@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from kotti.resources import get_root
 from kotti.resources import Document
+from kotti.resources import File
 from kotti.resources import Image
 
 from kotti_tinymce import KottiTinyMCE
@@ -54,11 +55,12 @@ def test_kottibrowser(db_session, dummy_request):
 
     kt = KottiTinyMCE(root, dummy_request)
     browser = kt.kottibrowser()
-    assert len(browser['image_scales']) == 12
-    assert browser['image_scales'][0] == \
-        {'size': [60, 120], 'title': 'span1', 'value': 'span1'}
+    # image_scales do no longer exist as of 0.4
+    # assert len(browser['image_scales']) == 12
+    # assert browser['image_scales'][0] == \
+    #     {'size': [60, 120], 'title': 'span1', 'value': 'span1'}
     assert browser['image_selectable'] is False
-    assert browser['image_url'] == 'http://example.com/image'
+    assert browser['image_url'] == 'http://example.com/image/span1'
     assert browser['link_selectable'] is True
     assert browser['upload_allowed'] is True
 
@@ -66,9 +68,9 @@ def test_kottibrowser(db_session, dummy_request):
     dummy_request.params['type'] = 'image'
     kt = KottiTinyMCE(image, dummy_request)
     browser = kt.kottibrowser()
-    assert len(browser['image_scales']) == 12
+    # assert len(browser['image_scales']) == 12
     assert browser['image_selectable'] is True
-    assert browser['image_url'] == 'http://example.com/image/image'
+    assert browser['image_url'] == 'http://example.com/image/image/span1'
     assert browser['link_selectable'] is False
     assert browser['upload_allowed'] is False
 
@@ -97,18 +99,20 @@ def test_upload(db_session, dummy_request):
     assert dummy_request.session.pop_flash('error') == \
         [u'Please select a file to upload.']
 
-    dummy_file.filename = 'file.txt'
-    dummy_file.type = 'text/plain'
+    dummy_file.filename = u'file.txt'
+    dummy_file.type = u'text/plain'
     res = kt.upload()
     assert res.status == '302 Found'
     assert res.location == 'http://example.com/title/@@kottibrowser'
     assert dummy_request.session.pop_flash('success') == \
         [u'Successfully uploaded.']
+    assert isinstance(root.get(u'title'), File)
 
-    dummy_file.filename = 'file.jpg'
-    dummy_file.type = 'image/jpeg'
+    dummy_file.filename = u'file.jpg'
+    dummy_file.type = u'image/jpeg'
     res = kt.upload()
     assert res.status == '302 Found'
     assert res.location == 'http://example.com/title-1/@@kottibrowser'
     assert dummy_request.session.pop_flash('success') == \
         [u'Successfully uploaded.']
+    assert isinstance(root.get(u'title-1'), Image)
